jobDuration constant
IriTerm
const jobDuration
jobDuration [Expects: http://schema.org/Duration, http://schema.org/QuantitativeValue]
The expected duration of an employment offer as advertised by the employer. Relevant for job postings that have a clearly defined period in mind such as seasonal work, substitutes for maternal leave or any other temporary employment.
Can be used on: http://schema.org/JobPosting
Implementation
static const jobDuration = IriTerm('http://schema.org/jobDuration');